========
passacre
========

The code is available on github: https://github.com/habnabit/passacre

.. include:: ../README.rst
   :start-line: 9

.. toctree::
   :maxdepth: 2

   faq
   commands
   schema
   config
   features
